# json-key-explorer

CLI tool to explore the keys in a JSON file.

## Use Case

Useful for discovering the various key paths inside a large JSON file. Ignore the unwanted clutter inside the JSON and focus on the path that is important to you.

## Installation

```
pip install jkx
```

## Usage

```
jkx file.json
```
